const system = require("../../../system");
var settings = require("../../../../config/settings");
var APIBase = require("../../api.base");

class TradetransferAPI extends APIBase {
  constructor() {
    super();
    this.execlient = system.getObject("util.execClient");
    this.utilsNeedSve = system.getObject("service.utilsSve.utilsNeedSve");
    this.channelApiUrl = settings.channelApiUrl();
    this.centerChannelUrl = settings.centerChannelUrl();
    this.appInfo = {
      aliyuntmtransfer: { appkey: settings.appKey, secret: settings.secret }
    };
  }

  async getToken() {
    var self = this;
    var reqTokenUrl = this.channelApiUrl + "/web/auth/accessAuth/getAppTokenByHosts";
    // var reqParam = self.appInfo["aliyuntmtransfer"];
    var reqParam = {
      "actionType": "getAppTokenByHosts",
      "actionBody": {}
    }
    // if (!reqParam.appkey || !reqParam.secret) {
    //   return system.getResult(null, "reqType类型有误，请求失败");
    // }
    var rtn = await this.execlient.execPost(reqParam, reqTokenUrl);
    if (!rtn.stdout) {
      return system.getResult(null, "获取token失败");
    }
    var tokenResult = JSON.parse(rtn.stdout);
    if (tokenResult.status == 0) {
      tokenResult.data.secret = reqParam.secret;
    }
    return tokenResult;
  }

  //订单创建
  // 2020 0828 lin 修改 匹配商标交易
  async acceptOrder(pobj,qobj,req) {
    if (!qobj.BizId) {
      return {
        "errorCode": "error",
        "errorMsg": "订单号不能为空",
        "module": { "orderNumber": "" },
        "eequestId": req.requestId,
        "success": false
      }
    }
    if (!qobj.UserName) {
      return {
        "errorCode": "error",
        "errorMsg": "用户不能为空",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      }
    }
    if (!qobj.Mobile) {
      return {
        "errorCode": "error",
        "errorMsg": "用户手机号不能为空",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      }
    }
    if (!qobj.Price) {
      return {
        "errorCode": "error",
        "errorMsg": "价格不能为空",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      }
    }
    if (!qobj.RegisterNumber) {
      return {
        "errorCode": "error",
        "errorMsg": "商标注册号不能为空",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      }
    }
    if (!qobj.Classification) {
      return {
        "errorCode": "error",
        "errorMsg": "商标国际一级分类不能为空",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      }
    }
    var sobj = {
      "actionProcess": "aliyuntmtransfer",
      "actionType": "tmAccept",
      "actionBody": {
        "bizId": qobj.BizId,
        "userName": qobj.UserName,
        "mobile": qobj.Mobile,
        "registerNumber": qobj.RegisterNumber,
        "classification": qobj.Classification,
        "price": qobj.Price,
        "channelItemCode":"tmjy",
        "payCode": "tmjy-1",
        "quantity":1,
        "totalSum": qobj.Price,
        "payTotalSum": qobj.Price,
        "channelOrder":{
          "channelServiceNo": qobj.BizId,
          "channelOrderNo": qobj.BizId
        }
      }
    }
    // 获取token
    var tokenInfo = await this.getToken();
    if (tokenInfo.status != 0) {
      return {
        "errorCode": "error",
        "errorMsg": "渠道验证失败",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      };
    }
    // 获取userpin
    var userparam = {
      actionType: "getLoginByUserName",
      actionBody: {
        "channelUserId": qobj.Mobile,
        "mobile": qobj.Mobile,
        "userName": qobj.UserName
      }
    };
    var url = settings.centerChannelUrl() + "/api/opreceive/accessAuth/springBoard";
    var userpinResultTmp = await this.execlient.execPostTK(userparam, url, tokenInfo.data.token);
    if (userpinResultTmp.status != 0 && userpinResultTmp.status != 2060) {
      return {
        "errorCode": "error",
        "errorMsg": "用户验证失败",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      };
    }
    // 调取channel 开始业务
    var url = this.channelApiUrl + "/web/opaction/tmOrder/springBoard";
    // var rtn = await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
    var rtn = rtn = await this.execlient.execDataPostByTokenUserPin(sobj, url, tokenInfo.data.token, userpinResultTmp.data.userpin);
    if (!rtn.stdout) {
      return {
        "errorCode": "error",
        "errorMsg": "建立订单失败",
        "module": { "orderNumber": "" },
        "requestId": req.requestId,
        "success": false
      };
    }
    return JSON.parse(rtn.stdout);
  }
  //订单查询
  async queryOrderState(p,obj) {
    var sobj = {
      "actionProcess": "aliyuntmtransfer",
      "actionType": "aliclient",
      "sign": "2FviZ9PGws8Pt1fBhq0t90mjUvI",
      "actionBody": p
    }
    var tokenInfo = await this.getToken();
    console.log(tokenInfo);
    var url = this.channelApiUrl + "/action/tradetransfer/ordersel";
    var rtn = await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
    console.log(rtn);
    // var rtn = await this.execlient.execPostTK(sobj, url,"token");
    return rtn;
  }

  //订单关闭
  async tmRefuse(p,obj,req) {
    var sobj = {
      "actionProcess": "aliyuntmtransfer",
      "actionType": "tmRefuse",
      "actionBody": {
        bizId: obj.BizId
      }
    }
    var tokenInfo = await this.getToken();
    var url = this.channelApiUrl + "/web/opaction/tmOrder/springBoard";
    var rtn = await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
    // var rtn = await this.execlient.execPostTK(sobj, url,"token");
    return rtn;
  }


  //查询咨询客户列表
  async queryTradeIntentionUserList(p,obj) {
    let sobj = {
      "actionType": "QueryTradeIntentionUserList",
    };
    let tokenInfo = await this.utilsNeedSve.getCenterToken();
    let url = this.centerChannelUrl + "/web/trade/brand/springBoard";
    return await this.execlient.execPostTK(sobj, url, tokenInfo.data.token);
  }

}
module.exports = TradetransferAPI;
